# coding: utf-8

"""
    model-configuration-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_model_configuration_service.api_client import ApiClient
from dhicn_model_configuration_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ScenarioApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v2_model_configuration_scenario_config_logs_get(self, **kwargs):  # noqa: E501
        """获取模板方案的配置进度 Get template scenario's configuration progress  # noqa: E501

        获取各个模板方案的配置进度，必要步骤必须完成配置之后模板方案才能启用 Get all the template scenarios' configuration progress information, necessary steps must be finished before the template scenario can be enabled.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_scenario_config_logs_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[TemplateScenarioLogOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_model_configuration_scenario_config_logs_get_with_http_info(**kwargs)  # noqa: E501

    def api_v2_model_configuration_scenario_config_logs_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取模板方案的配置进度 Get template scenario's configuration progress  # noqa: E501

        获取各个模板方案的配置进度，必要步骤必须完成配置之后模板方案才能启用 Get all the template scenarios' configuration progress information, necessary steps must be finished before the template scenario can be enabled.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_scenario_config_logs_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[TemplateScenarioLogOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_model_configuration_scenario_config_logs_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/model-configuration/scenario/config-logs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TemplateScenarioLogOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_model_configuration_scenario_create_template_scenario_post(self, **kwargs):  # noqa: E501
        """创建模板方案，导出模型基本信息 Create template scrnario, meanwhile export model info  # noqa: E501

        基于一个模板模型文件，创建模板方案，导出模型基本信息，同时会把相同库下面的其他模板方案禁用 Based on a template file to create a new template scenario, export model info, meanwhile disable all the old template scenarios of the same library.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_scenario_create_template_scenario_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str template_file_id: 模板模型文件ID model template file id
        :param str system_id: 系统ID system id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CreateTemplateScenarioOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_model_configuration_scenario_create_template_scenario_post_with_http_info(**kwargs)  # noqa: E501

    def api_v2_model_configuration_scenario_create_template_scenario_post_with_http_info(self, **kwargs):  # noqa: E501
        """创建模板方案，导出模型基本信息 Create template scrnario, meanwhile export model info  # noqa: E501

        基于一个模板模型文件，创建模板方案，导出模型基本信息，同时会把相同库下面的其他模板方案禁用 Based on a template file to create a new template scenario, export model info, meanwhile disable all the old template scenarios of the same library.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_scenario_create_template_scenario_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str template_file_id: 模板模型文件ID model template file id
        :param str system_id: 系统ID system id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CreateTemplateScenarioOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'template_file_id',
            'system_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_model_configuration_scenario_create_template_scenario_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'template_file_id' in local_var_params and local_var_params['template_file_id'] is not None:  # noqa: E501
            query_params.append(('templateFileId', local_var_params['template_file_id']))  # noqa: E501
        if 'system_id' in local_var_params and local_var_params['system_id'] is not None:  # noqa: E501
            query_params.append(('systemId', local_var_params['system_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/model-configuration/scenario/create-template-scenario', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateTemplateScenarioOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_model_configuration_scenario_enable_template_scenario_post(self, **kwargs):  # noqa: E501
        """启用历史模板方案 Enable template scenario  # noqa: E501

        启用一个历史的模板方案，同时禁用同一个库下的其他模板方案，只有完成了必要的配置流程的模板方案才能被启用 Turn on a history template scenario to be active, meanwhile disable all the other template scenarios of the same library.  Only a template scenario which has finished all the necessary initialization steps can be activated.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_scenario_enable_template_scenario_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 模板方案ID template scenario's id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_model_configuration_scenario_enable_template_scenario_post_with_http_info(**kwargs)  # noqa: E501

    def api_v2_model_configuration_scenario_enable_template_scenario_post_with_http_info(self, **kwargs):  # noqa: E501
        """启用历史模板方案 Enable template scenario  # noqa: E501

        启用一个历史的模板方案，同时禁用同一个库下的其他模板方案，只有完成了必要的配置流程的模板方案才能被启用 Turn on a history template scenario to be active, meanwhile disable all the other template scenarios of the same library.  Only a template scenario which has finished all the necessary initialization steps can be activated.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_scenario_enable_template_scenario_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 模板方案ID template scenario's id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_model_configuration_scenario_enable_template_scenario_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/model-configuration/scenario/enable-template-scenario', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_model_configuration_scenario_init_library_on_create_old_post(self, **kwargs):  # noqa: E501
        """Init library on create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_scenario_init_library_on_create_old_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param InitLibraryInput init_library_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[LibraryInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_model_configuration_scenario_init_library_on_create_old_post_with_http_info(**kwargs)  # noqa: E501

    def api_v2_model_configuration_scenario_init_library_on_create_old_post_with_http_info(self, **kwargs):  # noqa: E501
        """Init library on create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_scenario_init_library_on_create_old_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param InitLibraryInput init_library_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[LibraryInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tenant_id',
            'init_library_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_model_configuration_scenario_init_library_on_create_old_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'init_library_input' in local_var_params:
            body_params = local_var_params['init_library_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/model-configuration/scenario/init-library-on-create_old', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[LibraryInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_model_configuration_scenario_init_library_on_create_post(self, **kwargs):  # noqa: E501
        """/api/v2/model-configuration/scenario/init-library-on-create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_scenario_init_library_on_create_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param list[LibraryInfo] library_info:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[LibraryInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_model_configuration_scenario_init_library_on_create_post_with_http_info(**kwargs)  # noqa: E501

    def api_v2_model_configuration_scenario_init_library_on_create_post_with_http_info(self, **kwargs):  # noqa: E501
        """/api/v2/model-configuration/scenario/init-library-on-create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_scenario_init_library_on_create_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param list[LibraryInfo] library_info:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[LibraryInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tenant_id',
            'library_info'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_model_configuration_scenario_init_library_on_create_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'library_info' in local_var_params:
            body_params = local_var_params['library_info']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/model-configuration/scenario/init-library-on-create', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[LibraryInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_model_configuration_scenario_scenario_config_log_get(self, **kwargs):  # noqa: E501
        """根据模板方案ID获取模板方案的配置进度 Get template scenario's configuration progress by scenario id  # noqa: E501

        获取单个模板方案的配置进度，必要步骤必须完成配置之后模板方案才能启用 Get template scenario's configuration progress information by scenario id, necessary steps must be finished before the template scenario can be enabled.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_scenario_scenario_config_log_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: scenario id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[TemplateScenarioLogOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_model_configuration_scenario_scenario_config_log_get_with_http_info(**kwargs)  # noqa: E501

    def api_v2_model_configuration_scenario_scenario_config_log_get_with_http_info(self, **kwargs):  # noqa: E501
        """根据模板方案ID获取模板方案的配置进度 Get template scenario's configuration progress by scenario id  # noqa: E501

        获取单个模板方案的配置进度，必要步骤必须完成配置之后模板方案才能启用 Get template scenario's configuration progress information by scenario id, necessary steps must be finished before the template scenario can be enabled.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_scenario_scenario_config_log_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: scenario id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[TemplateScenarioLogOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_model_configuration_scenario_scenario_config_log_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/model-configuration/scenario/scenario-config-log', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TemplateScenarioLogOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    model-configuration-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_configuration_service.configuration import Configuration


class TemplateScenarioLogOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'scenario_id': 'str',
        'code': 'str',
        'description': 'str',
        'success': 'bool',
        'required': 'bool',
        'remark': 'str',
        'last_modification_time': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'scenario_id': 'scenarioId',
        'code': 'code',
        'description': 'description',
        'success': 'success',
        'required': 'required',
        'remark': 'remark',
        'last_modification_time': 'lastModificationTime'
    }

    def __init__(self, id=None, scenario_id=None, code=None, description=None, success=None, required=None, remark=None, last_modification_time=None, local_vars_configuration=None):  # noqa: E501
        """TemplateScenarioLogOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._scenario_id = None
        self._code = None
        self._description = None
        self._success = None
        self._required = None
        self._remark = None
        self._last_modification_time = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if scenario_id is not None:
            self.scenario_id = scenario_id
        self.code = code
        self.description = description
        if success is not None:
            self.success = success
        if required is not None:
            self.required = required
        self.remark = remark
        self.last_modification_time = last_modification_time

    @property
    def id(self):
        """Gets the id of this TemplateScenarioLogOutput.  # noqa: E501

        配置进度信息ID configuration progress id  # noqa: E501

        :return: The id of this TemplateScenarioLogOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TemplateScenarioLogOutput.

        配置进度信息ID configuration progress id  # noqa: E501

        :param id: The id of this TemplateScenarioLogOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def scenario_id(self):
        """Gets the scenario_id of this TemplateScenarioLogOutput.  # noqa: E501

        模板方案ID template scenario id  # noqa: E501

        :return: The scenario_id of this TemplateScenarioLogOutput.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this TemplateScenarioLogOutput.

        模板方案ID template scenario id  # noqa: E501

        :param scenario_id: The scenario_id of this TemplateScenarioLogOutput.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def code(self):
        """Gets the code of this TemplateScenarioLogOutput.  # noqa: E501

        配置步骤代码 configuration step code  # noqa: E501

        :return: The code of this TemplateScenarioLogOutput.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this TemplateScenarioLogOutput.

        配置步骤代码 configuration step code  # noqa: E501

        :param code: The code of this TemplateScenarioLogOutput.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def description(self):
        """Gets the description of this TemplateScenarioLogOutput.  # noqa: E501

        配置步骤描述 configuration step description  # noqa: E501

        :return: The description of this TemplateScenarioLogOutput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TemplateScenarioLogOutput.

        配置步骤描述 configuration step description  # noqa: E501

        :param description: The description of this TemplateScenarioLogOutput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def success(self):
        """Gets the success of this TemplateScenarioLogOutput.  # noqa: E501

        是否配置成功 if the configuration step is successful  # noqa: E501

        :return: The success of this TemplateScenarioLogOutput.  # noqa: E501
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this TemplateScenarioLogOutput.

        是否配置成功 if the configuration step is successful  # noqa: E501

        :param success: The success of this TemplateScenarioLogOutput.  # noqa: E501
        :type: bool
        """

        self._success = success

    @property
    def required(self):
        """Gets the required of this TemplateScenarioLogOutput.  # noqa: E501

        是否必需 if the configuration step is required  # noqa: E501

        :return: The required of this TemplateScenarioLogOutput.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this TemplateScenarioLogOutput.

        是否必需 if the configuration step is required  # noqa: E501

        :param required: The required of this TemplateScenarioLogOutput.  # noqa: E501
        :type: bool
        """

        self._required = required

    @property
    def remark(self):
        """Gets the remark of this TemplateScenarioLogOutput.  # noqa: E501

        备注 remark  # noqa: E501

        :return: The remark of this TemplateScenarioLogOutput.  # noqa: E501
        :rtype: str
        """
        return self._remark

    @remark.setter
    def remark(self, remark):
        """Sets the remark of this TemplateScenarioLogOutput.

        备注 remark  # noqa: E501

        :param remark: The remark of this TemplateScenarioLogOutput.  # noqa: E501
        :type: str
        """

        self._remark = remark

    @property
    def last_modification_time(self):
        """Gets the last_modification_time of this TemplateScenarioLogOutput.  # noqa: E501

        最后一次修改时间 last modify time  # noqa: E501

        :return: The last_modification_time of this TemplateScenarioLogOutput.  # noqa: E501
        :rtype: datetime
        """
        return self._last_modification_time

    @last_modification_time.setter
    def last_modification_time(self, last_modification_time):
        """Sets the last_modification_time of this TemplateScenarioLogOutput.

        最后一次修改时间 last modify time  # noqa: E501

        :param last_modification_time: The last_modification_time of this TemplateScenarioLogOutput.  # noqa: E501
        :type: datetime
        """

        self._last_modification_time = last_modification_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TemplateScenarioLogOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TemplateScenarioLogOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_iot_service.api_client import ApiClient
from dhicn_iot_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class IntegrationApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_iot_integration_delete_in_point_map_get(self, **kwargs):  # noqa: E501
        """删除输入点位映射关系  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_delete_in_point_map_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str template_id:
        :param str in_point_map_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_integration_delete_in_point_map_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_integration_delete_in_point_map_get_with_http_info(self, **kwargs):  # noqa: E501
        """删除输入点位映射关系  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_delete_in_point_map_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str template_id:
        :param str in_point_map_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'template_id',
            'in_point_map_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_integration_delete_in_point_map_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'template_id' in local_var_params and local_var_params['template_id'] is not None:  # noqa: E501
            query_params.append(('templateId', local_var_params['template_id']))  # noqa: E501
        if 'in_point_map_id' in local_var_params and local_var_params['in_point_map_id'] is not None:  # noqa: E501
            query_params.append(('InPointMapId', local_var_params['in_point_map_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/integration/delete-in-point-map', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_integration_export_iot_config_excel_post(self, **kwargs):  # noqa: E501
        """导出资产设备指标excel  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_export_iot_config_excel_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str template_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_integration_export_iot_config_excel_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_integration_export_iot_config_excel_post_with_http_info(self, **kwargs):  # noqa: E501
        """导出资产设备指标excel  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_export_iot_config_excel_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str template_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'template_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_integration_export_iot_config_excel_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'template_id' in local_var_params and local_var_params['template_id'] is not None:  # noqa: E501
            query_params.append(('templateId', local_var_params['template_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/integration/export-iot-config-excel', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_integration_get_inout_point_map_info_get(self, **kwargs):  # noqa: E501
        """获取输入输出点位映射信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_get_inout_point_map_info_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str template_id:
        :param list[str] assets: 资产列表
        :param list[str] devices: 设备列表
        :param list[str] device_indicators: 设备指标列表
        :param list[str] model_point_data_types: 模型点位数据类型列表,即: DeviceIndicatorId与ModelPointId、ModelDataType、TemplateId的关联关系
        :param list[str] model_boundary_configs: 模型边界列表
        :param list[str] template_ids: 模板Id列表
        :param list[str] model_points: 模型点位信息列表
        :param list[str] libraries: 项目所有方案类库列表
        :param list[str] template_scenarios: 类库下的所有模板方案
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PointMapAssemblyInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_integration_get_inout_point_map_info_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_integration_get_inout_point_map_info_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取输入输出点位映射信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_get_inout_point_map_info_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str template_id:
        :param list[str] assets: 资产列表
        :param list[str] devices: 设备列表
        :param list[str] device_indicators: 设备指标列表
        :param list[str] model_point_data_types: 模型点位数据类型列表,即: DeviceIndicatorId与ModelPointId、ModelDataType、TemplateId的关联关系
        :param list[str] model_boundary_configs: 模型边界列表
        :param list[str] template_ids: 模板Id列表
        :param list[str] model_points: 模型点位信息列表
        :param list[str] libraries: 项目所有方案类库列表
        :param list[str] template_scenarios: 类库下的所有模板方案
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PointMapAssemblyInfo, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'template_id',
            'assets',
            'devices',
            'device_indicators',
            'model_point_data_types',
            'model_boundary_configs',
            'template_ids',
            'model_points',
            'libraries',
            'template_scenarios'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_integration_get_inout_point_map_info_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'template_id' in local_var_params and local_var_params['template_id'] is not None:  # noqa: E501
            query_params.append(('templateId', local_var_params['template_id']))  # noqa: E501
        if 'assets' in local_var_params and local_var_params['assets'] is not None:  # noqa: E501
            query_params.append(('Assets', local_var_params['assets']))  # noqa: E501
            collection_formats['Assets'] = 'multi'  # noqa: E501
        if 'devices' in local_var_params and local_var_params['devices'] is not None:  # noqa: E501
            query_params.append(('Devices', local_var_params['devices']))  # noqa: E501
            collection_formats['Devices'] = 'multi'  # noqa: E501
        if 'device_indicators' in local_var_params and local_var_params['device_indicators'] is not None:  # noqa: E501
            query_params.append(('DeviceIndicators', local_var_params['device_indicators']))  # noqa: E501
            collection_formats['DeviceIndicators'] = 'multi'  # noqa: E501
        if 'model_point_data_types' in local_var_params and local_var_params['model_point_data_types'] is not None:  # noqa: E501
            query_params.append(('ModelPointDataTypes', local_var_params['model_point_data_types']))  # noqa: E501
            collection_formats['ModelPointDataTypes'] = 'multi'  # noqa: E501
        if 'model_boundary_configs' in local_var_params and local_var_params['model_boundary_configs'] is not None:  # noqa: E501
            query_params.append(('ModelBoundaryConfigs', local_var_params['model_boundary_configs']))  # noqa: E501
            collection_formats['ModelBoundaryConfigs'] = 'multi'  # noqa: E501
        if 'template_ids' in local_var_params and local_var_params['template_ids'] is not None:  # noqa: E501
            query_params.append(('TemplateIds', local_var_params['template_ids']))  # noqa: E501
            collection_formats['TemplateIds'] = 'multi'  # noqa: E501
        if 'model_points' in local_var_params and local_var_params['model_points'] is not None:  # noqa: E501
            query_params.append(('ModelPoints', local_var_params['model_points']))  # noqa: E501
            collection_formats['ModelPoints'] = 'multi'  # noqa: E501
        if 'libraries' in local_var_params and local_var_params['libraries'] is not None:  # noqa: E501
            query_params.append(('Libraries', local_var_params['libraries']))  # noqa: E501
            collection_formats['Libraries'] = 'multi'  # noqa: E501
        if 'template_scenarios' in local_var_params and local_var_params['template_scenarios'] is not None:  # noqa: E501
            query_params.append(('TemplateScenarios', local_var_params['template_scenarios']))  # noqa: E501
            collection_formats['TemplateScenarios'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/integration/get-inout-point-map-info', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PointMapAssemblyInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_integration_import_boundarymap_config_excel_post(self, **kwargs):  # noqa: E501
        """批量导入边界映射excel  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_import_boundarymap_config_excel_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str template_id:
        :param file excel_file:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StringListResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_integration_import_boundarymap_config_excel_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_integration_import_boundarymap_config_excel_post_with_http_info(self, **kwargs):  # noqa: E501
        """批量导入边界映射excel  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_import_boundarymap_config_excel_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str template_id:
        :param file excel_file:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StringListResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'template_id',
            'excel_file'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_integration_import_boundarymap_config_excel_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'template_id' in local_var_params and local_var_params['template_id'] is not None:  # noqa: E501
            query_params.append(('templateId', local_var_params['template_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'excel_file' in local_var_params:
            local_var_files['excelFile'] = local_var_params['excel_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/integration/import-boundarymap-config-excel', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StringListResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_integration_import_iot_config_excel_post(self, **kwargs):  # noqa: E501
        """批量导入资产设备指标excel  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_import_iot_config_excel_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str template_id:
        :param file excel_file:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StringListResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_integration_import_iot_config_excel_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_integration_import_iot_config_excel_post_with_http_info(self, **kwargs):  # noqa: E501
        """批量导入资产设备指标excel  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_import_iot_config_excel_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str template_id:
        :param file excel_file:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StringListResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'template_id',
            'excel_file'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_integration_import_iot_config_excel_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'template_id' in local_var_params and local_var_params['template_id'] is not None:  # noqa: E501
            query_params.append(('templateId', local_var_params['template_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'excel_file' in local_var_params:
            local_var_files['excelFile'] = local_var_params['excel_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/integration/import-iot-config-excel', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StringListResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_integration_import_pointmap_config_excel_post(self, **kwargs):  # noqa: E501
        """批量导入点位映射excel  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_import_pointmap_config_excel_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str template_id:
        :param file excel_file:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StringListResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_integration_import_pointmap_config_excel_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_integration_import_pointmap_config_excel_post_with_http_info(self, **kwargs):  # noqa: E501
        """批量导入点位映射excel  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_import_pointmap_config_excel_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str template_id:
        :param file excel_file:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StringListResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'template_id',
            'excel_file'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_integration_import_pointmap_config_excel_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'template_id' in local_var_params and local_var_params['template_id'] is not None:  # noqa: E501
            query_params.append(('templateId', local_var_params['template_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'excel_file' in local_var_params:
            local_var_files['excelFile'] = local_var_params['excel_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/integration/import-pointmap-config-excel', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StringListResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_integration_save_in_point_map_post(self, **kwargs):  # noqa: E501
        """保存模型输入点位映射关系  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_save_in_point_map_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param InPointMap in_point_map:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_integration_save_in_point_map_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_integration_save_in_point_map_post_with_http_info(self, **kwargs):  # noqa: E501
        """保存模型输入点位映射关系  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_save_in_point_map_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param InPointMap in_point_map:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'in_point_map'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_integration_save_in_point_map_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'in_point_map' in local_var_params:
            body_params = local_var_params['in_point_map']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/integration/save-in-point-map', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_integration_save_out_point_map_post(self, **kwargs):  # noqa: E501
        """保存模型输出点位映射关系  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_save_out_point_map_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SaveOutPointMapInput save_out_point_map_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_integration_save_out_point_map_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_integration_save_out_point_map_post_with_http_info(self, **kwargs):  # noqa: E501
        """保存模型输出点位映射关系  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_save_out_point_map_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SaveOutPointMapInput save_out_point_map_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'save_out_point_map_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_integration_save_out_point_map_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'save_out_point_map_input' in local_var_params:
            body_params = local_var_params['save_out_point_map_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/integration/save-out-point-map', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_integration_search_get_inout_point_map_info_post(self, **kwargs):  # noqa: E501
        """通过设备、指标,检索:实测指标--与--模型输出点位,映射关系;实测指标--与--模型边界点位,映射关系  Through equipment and indicator, search: measured indicator -- and -- model point, mapping relationship;   Measured indicator -- and -- model boundary point, mapping relationship  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_search_get_inout_point_map_info_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SearchInOutPointMapAssemblyInput search_in_out_point_map_assembly_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PointMapAssemblyInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_integration_search_get_inout_point_map_info_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_integration_search_get_inout_point_map_info_post_with_http_info(self, **kwargs):  # noqa: E501
        """通过设备、指标,检索:实测指标--与--模型输出点位,映射关系;实测指标--与--模型边界点位,映射关系  Through equipment and indicator, search: measured indicator -- and -- model point, mapping relationship;   Measured indicator -- and -- model boundary point, mapping relationship  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_integration_search_get_inout_point_map_info_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SearchInOutPointMapAssemblyInput search_in_out_point_map_assembly_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PointMapAssemblyInfo, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'search_in_out_point_map_assembly_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_integration_search_get_inout_point_map_info_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'search_in_out_point_map_assembly_input' in local_var_params:
            body_params = local_var_params['search_in_out_point_map_assembly_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/integration/search/get-inout-point-map-info', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PointMapAssemblyInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    accident-manager-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_accident_management_service.configuration import Configuration


class EventInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'scene_id': 'str',
        'name': 'str',
        'discharge_type': 'DischargeTypeEnum',
        'start_time': 'datetime',
        'end_time': 'datetime',
        'discharge': 'float',
        'discharge_ts': 'str',
        'location': 'str',
        'remark': 'str',
        'event_type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'scene_id': 'sceneId',
        'name': 'name',
        'discharge_type': 'dischargeType',
        'start_time': 'startTime',
        'end_time': 'endTime',
        'discharge': 'discharge',
        'discharge_ts': 'dischargeTS',
        'location': 'location',
        'remark': 'remark',
        'event_type': 'eventType'
    }

    def __init__(self, id=None, scene_id=None, name=None, discharge_type=None, start_time=None, end_time=None, discharge=None, discharge_ts=None, location=None, remark=None, event_type=None, local_vars_configuration=None):  # noqa: E501
        """EventInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._scene_id = None
        self._name = None
        self._discharge_type = None
        self._start_time = None
        self._end_time = None
        self._discharge = None
        self._discharge_ts = None
        self._location = None
        self._remark = None
        self._event_type = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if scene_id is not None:
            self.scene_id = scene_id
        self.name = name
        if discharge_type is not None:
            self.discharge_type = discharge_type
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if discharge is not None:
            self.discharge = discharge
        self.discharge_ts = discharge_ts
        self.location = location
        self.remark = remark
        self.event_type = event_type

    @property
    def id(self):
        """Gets the id of this EventInfo.  # noqa: E501

        事件ID event id  # noqa: E501

        :return: The id of this EventInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EventInfo.

        事件ID event id  # noqa: E501

        :param id: The id of this EventInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def scene_id(self):
        """Gets the scene_id of this EventInfo.  # noqa: E501

        情景ID scene id  # noqa: E501

        :return: The scene_id of this EventInfo.  # noqa: E501
        :rtype: str
        """
        return self._scene_id

    @scene_id.setter
    def scene_id(self, scene_id):
        """Sets the scene_id of this EventInfo.

        情景ID scene id  # noqa: E501

        :param scene_id: The scene_id of this EventInfo.  # noqa: E501
        :type: str
        """

        self._scene_id = scene_id

    @property
    def name(self):
        """Gets the name of this EventInfo.  # noqa: E501

        事件名称 event name  # noqa: E501

        :return: The name of this EventInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this EventInfo.

        事件名称 event name  # noqa: E501

        :param name: The name of this EventInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def discharge_type(self):
        """Gets the discharge_type of this EventInfo.  # noqa: E501


        :return: The discharge_type of this EventInfo.  # noqa: E501
        :rtype: DischargeTypeEnum
        """
        return self._discharge_type

    @discharge_type.setter
    def discharge_type(self, discharge_type):
        """Sets the discharge_type of this EventInfo.


        :param discharge_type: The discharge_type of this EventInfo.  # noqa: E501
        :type: DischargeTypeEnum
        """

        self._discharge_type = discharge_type

    @property
    def start_time(self):
        """Gets the start_time of this EventInfo.  # noqa: E501

        事件开始时间 event start time  # noqa: E501

        :return: The start_time of this EventInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this EventInfo.

        事件开始时间 event start time  # noqa: E501

        :param start_time: The start_time of this EventInfo.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this EventInfo.  # noqa: E501

        事件结束时间 event end time  # noqa: E501

        :return: The end_time of this EventInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this EventInfo.

        事件结束时间 event end time  # noqa: E501

        :param end_time: The end_time of this EventInfo.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def discharge(self):
        """Gets the discharge of this EventInfo.  # noqa: E501

        流量 discharge  # noqa: E501

        :return: The discharge of this EventInfo.  # noqa: E501
        :rtype: float
        """
        return self._discharge

    @discharge.setter
    def discharge(self, discharge):
        """Sets the discharge of this EventInfo.

        流量 discharge  # noqa: E501

        :param discharge: The discharge of this EventInfo.  # noqa: E501
        :type: float
        """

        self._discharge = discharge

    @property
    def discharge_ts(self):
        """Gets the discharge_ts of this EventInfo.  # noqa: E501

        流量时间序列ID discharge time series id  # noqa: E501

        :return: The discharge_ts of this EventInfo.  # noqa: E501
        :rtype: str
        """
        return self._discharge_ts

    @discharge_ts.setter
    def discharge_ts(self, discharge_ts):
        """Sets the discharge_ts of this EventInfo.

        流量时间序列ID discharge time series id  # noqa: E501

        :param discharge_ts: The discharge_ts of this EventInfo.  # noqa: E501
        :type: str
        """

        self._discharge_ts = discharge_ts

    @property
    def location(self):
        """Gets the location of this EventInfo.  # noqa: E501

        事件地点 event location  # noqa: E501

        :return: The location of this EventInfo.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this EventInfo.

        事件地点 event location  # noqa: E501

        :param location: The location of this EventInfo.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def remark(self):
        """Gets the remark of this EventInfo.  # noqa: E501

        事件备注 event remark  # noqa: E501

        :return: The remark of this EventInfo.  # noqa: E501
        :rtype: str
        """
        return self._remark

    @remark.setter
    def remark(self, remark):
        """Sets the remark of this EventInfo.

        事件备注 event remark  # noqa: E501

        :param remark: The remark of this EventInfo.  # noqa: E501
        :type: str
        """

        self._remark = remark

    @property
    def event_type(self):
        """Gets the event_type of this EventInfo.  # noqa: E501

        事件类型 event type  # noqa: E501

        :return: The event_type of this EventInfo.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this EventInfo.

        事件类型 event type  # noqa: E501

        :param event_type: The event_type of this EventInfo.  # noqa: E501
        :type: str
        """

        self._event_type = event_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EventInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class WqOnlinePoint(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'product_line': 'str',
        'codes': 'list[str]',
        'units': 'list[str]',
        'point_codes': 'list[str]'
    }

    attribute_map = {
        'product_line': 'productLine',
        'codes': 'codes',
        'units': 'units',
        'point_codes': 'pointCodes'
    }

    def __init__(self, product_line=None, codes=None, units=None, point_codes=None, local_vars_configuration=None):  # noqa: E501
        """WqOnlinePoint - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._product_line = None
        self._codes = None
        self._units = None
        self._point_codes = None
        self.discriminator = None

        self.product_line = product_line
        self.codes = codes
        self.units = units
        self.point_codes = point_codes

    @property
    def product_line(self):
        """Gets the product_line of this WqOnlinePoint.  # noqa: E501

        进水点或工艺线 inlet name or product line name  # noqa: E501

        :return: The product_line of this WqOnlinePoint.  # noqa: E501
        :rtype: str
        """
        return self._product_line

    @product_line.setter
    def product_line(self, product_line):
        """Sets the product_line of this WqOnlinePoint.

        进水点或工艺线 inlet name or product line name  # noqa: E501

        :param product_line: The product_line of this WqOnlinePoint.  # noqa: E501
        :type: str
        """

        self._product_line = product_line

    @property
    def codes(self):
        """Gets the codes of this WqOnlinePoint.  # noqa: E501

        系统点位列表 system point codes/indicators  # noqa: E501

        :return: The codes of this WqOnlinePoint.  # noqa: E501
        :rtype: list[str]
        """
        return self._codes

    @codes.setter
    def codes(self, codes):
        """Sets the codes of this WqOnlinePoint.

        系统点位列表 system point codes/indicators  # noqa: E501

        :param codes: The codes of this WqOnlinePoint.  # noqa: E501
        :type: list[str]
        """

        self._codes = codes

    @property
    def units(self):
        """Gets the units of this WqOnlinePoint.  # noqa: E501

        单位列表 units  # noqa: E501

        :return: The units of this WqOnlinePoint.  # noqa: E501
        :rtype: list[str]
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this WqOnlinePoint.

        单位列表 units  # noqa: E501

        :param units: The units of this WqOnlinePoint.  # noqa: E501
        :type: list[str]
        """

        self._units = units

    @property
    def point_codes(self):
        """Gets the point_codes of this WqOnlinePoint.  # noqa: E501

        在线点位列表 corresponding online point codes  # noqa: E501

        :return: The point_codes of this WqOnlinePoint.  # noqa: E501
        :rtype: list[str]
        """
        return self._point_codes

    @point_codes.setter
    def point_codes(self, point_codes):
        """Sets the point_codes of this WqOnlinePoint.

        在线点位列表 corresponding online point codes  # noqa: E501

        :param point_codes: The point_codes of this WqOnlinePoint.  # noqa: E501
        :type: list[str]
        """

        self._point_codes = point_codes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WqOnlinePoint):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WqOnlinePoint):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class SaveOutPointMapInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'device_name': 'str',
        'indicator': 'str',
        'model_point_type': 'str',
        'model_id': 'str',
        'model_data_type': 'str',
        'model_component': 'str',
        'template_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'device_name': 'deviceName',
        'indicator': 'indicator',
        'model_point_type': 'modelPointType',
        'model_id': 'modelId',
        'model_data_type': 'modelDataType',
        'model_component': 'modelComponent',
        'template_id': 'templateId'
    }

    def __init__(self, id=None, device_name=None, indicator=None, model_point_type=None, model_id=None, model_data_type=None, model_component=None, template_id=None, local_vars_configuration=None):  # noqa: E501
        """SaveOutPointMapInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._device_name = None
        self._indicator = None
        self._model_point_type = None
        self._model_id = None
        self._model_data_type = None
        self._model_component = None
        self._template_id = None
        self.discriminator = None

        self.id = id
        self.device_name = device_name
        self.indicator = indicator
        self.model_point_type = model_point_type
        self.model_id = model_id
        self.model_data_type = model_data_type
        self.model_component = model_component
        if template_id is not None:
            self.template_id = template_id

    @property
    def id(self):
        """Gets the id of this SaveOutPointMapInput.  # noqa: E501


        :return: The id of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SaveOutPointMapInput.


        :param id: The id of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def device_name(self):
        """Gets the device_name of this SaveOutPointMapInput.  # noqa: E501


        :return: The device_name of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._device_name

    @device_name.setter
    def device_name(self, device_name):
        """Sets the device_name of this SaveOutPointMapInput.


        :param device_name: The device_name of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._device_name = device_name

    @property
    def indicator(self):
        """Gets the indicator of this SaveOutPointMapInput.  # noqa: E501


        :return: The indicator of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """Sets the indicator of this SaveOutPointMapInput.


        :param indicator: The indicator of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._indicator = indicator

    @property
    def model_point_type(self):
        """Gets the model_point_type of this SaveOutPointMapInput.  # noqa: E501


        :return: The model_point_type of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._model_point_type

    @model_point_type.setter
    def model_point_type(self, model_point_type):
        """Sets the model_point_type of this SaveOutPointMapInput.


        :param model_point_type: The model_point_type of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._model_point_type = model_point_type

    @property
    def model_id(self):
        """Gets the model_id of this SaveOutPointMapInput.  # noqa: E501


        :return: The model_id of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this SaveOutPointMapInput.


        :param model_id: The model_id of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._model_id = model_id

    @property
    def model_data_type(self):
        """Gets the model_data_type of this SaveOutPointMapInput.  # noqa: E501


        :return: The model_data_type of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._model_data_type

    @model_data_type.setter
    def model_data_type(self, model_data_type):
        """Sets the model_data_type of this SaveOutPointMapInput.


        :param model_data_type: The model_data_type of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._model_data_type = model_data_type

    @property
    def model_component(self):
        """Gets the model_component of this SaveOutPointMapInput.  # noqa: E501


        :return: The model_component of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._model_component

    @model_component.setter
    def model_component(self, model_component):
        """Sets the model_component of this SaveOutPointMapInput.


        :param model_component: The model_component of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._model_component = model_component

    @property
    def template_id(self):
        """Gets the template_id of this SaveOutPointMapInput.  # noqa: E501


        :return: The template_id of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this SaveOutPointMapInput.


        :param template_id: The template_id of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._template_id = template_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SaveOutPointMapInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SaveOutPointMapInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class OutletResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'outlet_id': 'str',
        'start': 'str',
        'end': 'str',
        'flushing_duration': 'str',
        'required_duration': 'str',
        'static_pressure': 'float',
        'residual_pressure': 'float',
        'avg_discharge': 'float',
        'water_volume': 'float',
        'avg_flush_success': 'float',
        'avg_flush_velocity': 'float',
        'comment': 'str'
    }

    attribute_map = {
        'outlet_id': 'outletID',
        'start': 'start',
        'end': 'end',
        'flushing_duration': 'flushingDuration',
        'required_duration': 'requiredDuration',
        'static_pressure': 'staticPressure',
        'residual_pressure': 'residualPressure',
        'avg_discharge': 'avgDischarge',
        'water_volume': 'waterVolume',
        'avg_flush_success': 'avgFlushSuccess',
        'avg_flush_velocity': 'avgFlushVelocity',
        'comment': 'comment'
    }

    def __init__(self, outlet_id=None, start=None, end=None, flushing_duration=None, required_duration=None, static_pressure=None, residual_pressure=None, avg_discharge=None, water_volume=None, avg_flush_success=None, avg_flush_velocity=None, comment=None, local_vars_configuration=None):  # noqa: E501
        """OutletResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._outlet_id = None
        self._start = None
        self._end = None
        self._flushing_duration = None
        self._required_duration = None
        self._static_pressure = None
        self._residual_pressure = None
        self._avg_discharge = None
        self._water_volume = None
        self._avg_flush_success = None
        self._avg_flush_velocity = None
        self._comment = None
        self.discriminator = None

        self.outlet_id = outlet_id
        self.start = start
        self.end = end
        self.flushing_duration = flushing_duration
        self.required_duration = required_duration
        if static_pressure is not None:
            self.static_pressure = static_pressure
        if residual_pressure is not None:
            self.residual_pressure = residual_pressure
        if avg_discharge is not None:
            self.avg_discharge = avg_discharge
        if water_volume is not None:
            self.water_volume = water_volume
        if avg_flush_success is not None:
            self.avg_flush_success = avg_flush_success
        if avg_flush_velocity is not None:
            self.avg_flush_velocity = avg_flush_velocity
        self.comment = comment

    @property
    def outlet_id(self):
        """Gets the outlet_id of this OutletResult.  # noqa: E501


        :return: The outlet_id of this OutletResult.  # noqa: E501
        :rtype: str
        """
        return self._outlet_id

    @outlet_id.setter
    def outlet_id(self, outlet_id):
        """Sets the outlet_id of this OutletResult.


        :param outlet_id: The outlet_id of this OutletResult.  # noqa: E501
        :type: str
        """

        self._outlet_id = outlet_id

    @property
    def start(self):
        """Gets the start of this OutletResult.  # noqa: E501


        :return: The start of this OutletResult.  # noqa: E501
        :rtype: str
        """
        return self._start

    @start.setter
    def start(self, start):
        """Sets the start of this OutletResult.


        :param start: The start of this OutletResult.  # noqa: E501
        :type: str
        """

        self._start = start

    @property
    def end(self):
        """Gets the end of this OutletResult.  # noqa: E501


        :return: The end of this OutletResult.  # noqa: E501
        :rtype: str
        """
        return self._end

    @end.setter
    def end(self, end):
        """Sets the end of this OutletResult.


        :param end: The end of this OutletResult.  # noqa: E501
        :type: str
        """

        self._end = end

    @property
    def flushing_duration(self):
        """Gets the flushing_duration of this OutletResult.  # noqa: E501


        :return: The flushing_duration of this OutletResult.  # noqa: E501
        :rtype: str
        """
        return self._flushing_duration

    @flushing_duration.setter
    def flushing_duration(self, flushing_duration):
        """Sets the flushing_duration of this OutletResult.


        :param flushing_duration: The flushing_duration of this OutletResult.  # noqa: E501
        :type: str
        """

        self._flushing_duration = flushing_duration

    @property
    def required_duration(self):
        """Gets the required_duration of this OutletResult.  # noqa: E501


        :return: The required_duration of this OutletResult.  # noqa: E501
        :rtype: str
        """
        return self._required_duration

    @required_duration.setter
    def required_duration(self, required_duration):
        """Sets the required_duration of this OutletResult.


        :param required_duration: The required_duration of this OutletResult.  # noqa: E501
        :type: str
        """

        self._required_duration = required_duration

    @property
    def static_pressure(self):
        """Gets the static_pressure of this OutletResult.  # noqa: E501


        :return: The static_pressure of this OutletResult.  # noqa: E501
        :rtype: float
        """
        return self._static_pressure

    @static_pressure.setter
    def static_pressure(self, static_pressure):
        """Sets the static_pressure of this OutletResult.


        :param static_pressure: The static_pressure of this OutletResult.  # noqa: E501
        :type: float
        """

        self._static_pressure = static_pressure

    @property
    def residual_pressure(self):
        """Gets the residual_pressure of this OutletResult.  # noqa: E501


        :return: The residual_pressure of this OutletResult.  # noqa: E501
        :rtype: float
        """
        return self._residual_pressure

    @residual_pressure.setter
    def residual_pressure(self, residual_pressure):
        """Sets the residual_pressure of this OutletResult.


        :param residual_pressure: The residual_pressure of this OutletResult.  # noqa: E501
        :type: float
        """

        self._residual_pressure = residual_pressure

    @property
    def avg_discharge(self):
        """Gets the avg_discharge of this OutletResult.  # noqa: E501


        :return: The avg_discharge of this OutletResult.  # noqa: E501
        :rtype: float
        """
        return self._avg_discharge

    @avg_discharge.setter
    def avg_discharge(self, avg_discharge):
        """Sets the avg_discharge of this OutletResult.


        :param avg_discharge: The avg_discharge of this OutletResult.  # noqa: E501
        :type: float
        """

        self._avg_discharge = avg_discharge

    @property
    def water_volume(self):
        """Gets the water_volume of this OutletResult.  # noqa: E501


        :return: The water_volume of this OutletResult.  # noqa: E501
        :rtype: float
        """
        return self._water_volume

    @water_volume.setter
    def water_volume(self, water_volume):
        """Sets the water_volume of this OutletResult.


        :param water_volume: The water_volume of this OutletResult.  # noqa: E501
        :type: float
        """

        self._water_volume = water_volume

    @property
    def avg_flush_success(self):
        """Gets the avg_flush_success of this OutletResult.  # noqa: E501


        :return: The avg_flush_success of this OutletResult.  # noqa: E501
        :rtype: float
        """
        return self._avg_flush_success

    @avg_flush_success.setter
    def avg_flush_success(self, avg_flush_success):
        """Sets the avg_flush_success of this OutletResult.


        :param avg_flush_success: The avg_flush_success of this OutletResult.  # noqa: E501
        :type: float
        """

        self._avg_flush_success = avg_flush_success

    @property
    def avg_flush_velocity(self):
        """Gets the avg_flush_velocity of this OutletResult.  # noqa: E501


        :return: The avg_flush_velocity of this OutletResult.  # noqa: E501
        :rtype: float
        """
        return self._avg_flush_velocity

    @avg_flush_velocity.setter
    def avg_flush_velocity(self, avg_flush_velocity):
        """Sets the avg_flush_velocity of this OutletResult.


        :param avg_flush_velocity: The avg_flush_velocity of this OutletResult.  # noqa: E501
        :type: float
        """

        self._avg_flush_velocity = avg_flush_velocity

    @property
    def comment(self):
        """Gets the comment of this OutletResult.  # noqa: E501


        :return: The comment of this OutletResult.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this OutletResult.


        :param comment: The comment of this OutletResult.  # noqa: E501
        :type: str
        """

        self._comment = comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OutletResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OutletResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    wwtp-paas-infrastructure-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from dhicn_wwtp_infrastructure_service.api.alarm_api import AlarmApi
from dhicn_wwtp_infrastructure_service.api.base_api import BaseApi
from dhicn_wwtp_infrastructure_service.api.cache_api import CacheApi
from dhicn_wwtp_infrastructure_service.api.code_config_api import CodeConfigApi
from dhicn_wwtp_infrastructure_service.api.data_api import DataApi
from dhicn_wwtp_infrastructure_service.api.dosing_log_api import DosingLogApi
from dhicn_wwtp_infrastructure_service.api.import_export_api import ImportExportApi
from dhicn_wwtp_infrastructure_service.api.model_config_api import ModelConfigApi
from dhicn_wwtp_infrastructure_service.api.template_api import TemplateApi

# import ApiClient
from dhicn_wwtp_infrastructure_service.api_client import ApiClient
from dhicn_wwtp_infrastructure_service.configuration import Configuration
from dhicn_wwtp_infrastructure_service.exceptions import OpenApiException
from dhicn_wwtp_infrastructure_service.exceptions import ApiTypeError
from dhicn_wwtp_infrastructure_service.exceptions import ApiValueError
from dhicn_wwtp_infrastructure_service.exceptions import ApiKeyError
from dhicn_wwtp_infrastructure_service.exceptions import ApiException
# import models into sdk package
from dhicn_wwtp_infrastructure_service.models.add_or_update_online_datas_input import AddOrUpdateOnlineDatasInput
from dhicn_wwtp_infrastructure_service.models.alarm_config_in_out import AlarmConfigInOut
from dhicn_wwtp_infrastructure_service.models.alarm_log_inout import AlarmLogInout
from dhicn_wwtp_infrastructure_service.models.alarm_log_input import AlarmLogInput
from dhicn_wwtp_infrastructure_service.models.assembly_config import AssemblyConfig
from dhicn_wwtp_infrastructure_service.models.assembly_config_output import AssemblyConfigOutput
from dhicn_wwtp_infrastructure_service.models.base_product_line_in_out import BaseProductLineInOut
from dhicn_wwtp_infrastructure_service.models.code_assembly import CodeAssembly
from dhicn_wwtp_infrastructure_service.models.data_clean_tag_config_output import DataCleanTagConfigOutput
from dhicn_wwtp_infrastructure_service.models.dosage_basic_info import DosageBasicInfo
from dhicn_wwtp_infrastructure_service.models.dosing_log_dto import DosingLogDto
from dhicn_wwtp_infrastructure_service.models.get_assembly_config_input import GetAssemblyConfigInput
from dhicn_wwtp_infrastructure_service.models.get_model_ts_data_input2 import GetModelTsDataInput2
from dhicn_wwtp_infrastructure_service.models.get_online_ts_data_input import GetOnlineTsDataInput
from dhicn_wwtp_infrastructure_service.models.get_output_cost_per_flows_input import GetOutputCostPerFlowsInput
from dhicn_wwtp_infrastructure_service.models.get_output_model_precisions_input import GetOutputModelPrecisionsInput
from dhicn_wwtp_infrastructure_service.models.inline_object import InlineObject
from dhicn_wwtp_infrastructure_service.models.insert_online_processed_datas_input import InsertOnlineProcessedDatasInput
from dhicn_wwtp_infrastructure_service.models.mapping_config import MappingConfig
from dhicn_wwtp_infrastructure_service.models.mapping_config_input_output import MappingConfigInputOutput
from dhicn_wwtp_infrastructure_service.models.model_input_file_config_output import ModelInputFileConfigOutput
from dhicn_wwtp_infrastructure_service.models.model_node_config import ModelNodeConfig
from dhicn_wwtp_infrastructure_service.models.model_node_config_input_output import ModelNodeConfigInputOutput
from dhicn_wwtp_infrastructure_service.models.model_parameter_config_output import ModelParameterConfigOutput
from dhicn_wwtp_infrastructure_service.models.model_parameter_input_output import ModelParameterInputOutput
from dhicn_wwtp_infrastructure_service.models.modify_model_parameter_config_value_input import ModifyModelParameterConfigValueInput
from dhicn_wwtp_infrastructure_service.models.modify_online_processed_datas_input import ModifyOnlineProcessedDatasInput
from dhicn_wwtp_infrastructure_service.models.online_point_config import OnlinePointConfig
from dhicn_wwtp_infrastructure_service.models.online_point_config_input_output import OnlinePointConfigInputOutput
from dhicn_wwtp_infrastructure_service.models.output_cost_per_flow_output import OutputCostPerFlowOutput
from dhicn_wwtp_infrastructure_service.models.output_model_precision_output import OutputModelPrecisionOutput
from dhicn_wwtp_infrastructure_service.models.query_by_time import QueryByTime
from dhicn_wwtp_infrastructure_service.models.query_online_processed_datas_input import QueryOnlineProcessedDatasInput
from dhicn_wwtp_infrastructure_service.models.query_online_source_datas_input import QueryOnlineSourceDatasInput
from dhicn_wwtp_infrastructure_service.models.remote_service_error_info import RemoteServiceErrorInfo
from dhicn_wwtp_infrastructure_service.models.remote_service_error_response import RemoteServiceErrorResponse
from dhicn_wwtp_infrastructure_service.models.remote_service_validation_error_info import RemoteServiceValidationErrorInfo
from dhicn_wwtp_infrastructure_service.models.string_list_result import StringListResult
from dhicn_wwtp_infrastructure_service.models.sys_code_config_input_output import SysCodeConfigInputOutput
from dhicn_wwtp_infrastructure_service.models.template_output import TemplateOutput
from dhicn_wwtp_infrastructure_service.models.ts_data_input_output import TsDataInputOutput
from dhicn_wwtp_infrastructure_service.models.update_iot_input import UpdateIotInput
from dhicn_wwtp_infrastructure_service.models.update_latest_tag_input import UpdateLatestTagInput

